@@ -488,6 +488,8 @@ class BaseOptimizer(ABC):
                  max_evals=100,
                  max_rounds=5000,
                  early_stopping=50,
+                 n_folds=5,
+                 folds=None,
                  savepath=None):
         """
         Performs max_evals using Hyperopt to obtain the best parameters
@@ -512,7 +514,7 @@ class BaseOptimizer(ABC):
 
         # Build objective function
         if objective is None:
-            objective = self.get_obj(X_train, y_train, cat_features, max_rounds, early_stopping)
+            objective = self.get_obj(X_train, y_train, cat_features=cat_features, n_folds=n_folds, folds=folds,  max_rounds=max_rounds, early_stopping=early_stopping)
 
         # Run the optimization
         self.trials = Trials()
